import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Input, Output, Directive, ElementRef, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as jqueryImport from 'jquery';
import 'eonasdan-bootstrap-datetimepicker';

const DATETIME_FORMAT = 'DD/MM/YYYY HH:mm:ss';
const DATE_FORMAT = 'DD/MM/YYYY';
const TIME_FORMAT = 'DD/MM/YYYY';

const jquery = jqueryImport;
let NgTsDatepickerDirective = class NgTsDatepickerDirective {
    constructor(el) {
        this.el = el;
        /**
         * Emits date selected from datepicker
         */
        this.dateChange = new EventEmitter();
        /**
         * Emits empty value once datepicker is clicked
         */
        this.click = new EventEmitter();
        this.defaultOptions = {
            allowInputToggle: true,
            format: DATETIME_FORMAT,
            preventInputKeys: true
        };
        this.hasParent = false;
        this.internalOptions = {};
    }
    ngOnInit() {
        this.internalOptions = Object.assign(this.internalOptions, this.defaultOptions, this.options);
        const $parent = jquery(this.el.nativeElement.parentNode);
        this.dpElement = $parent.hasClass('input-group') ? $parent : jquery(this.el.nativeElement);
        if ($parent.hasClass('input-group')) {
            this.dpElement = $parent;
            this.hasParent = true;
        }
        else {
            this.dpElement = jquery(this.el.nativeElement);
        }
        this.appendCalendarIcon();
        const datepickerOptions = Object.assign({}, this.internalOptions);
        delete datepickerOptions.preventInputKeys;
        this.dpElement.datetimepicker(datepickerOptions);
        this.dpElement.data('DateTimePicker').date(this.date);
        this.dpElement.on('dp.change', (e) => {
            if (e.date !== this.date) {
                this.date = e.date;
                this.dateChange.emit(e.date);
            }
        });
        if (this.internalOptions.preventInputKeys) {
            this.dpElement.on('keydown', (e) => {
                e.preventDefault();
            });
        }
        this.dpElement.on('click', (e) => {
            this.click.emit();
        });
    }
    ngOnChanges(changes) {
        if (this.dpElement) {
            const dpe = this.dpElement.data('DateTimePicker');
            if (!!dpe) {
                if (changes.options) {
                    jquery.map(changes.options.currentValue, (value, key) => {
                        dpe[key](value);
                    });
                }
                if (changes.date && changes.date.currentValue !== undefined) {
                    dpe.date(changes.date.currentValue);
                }
                else {
                    dpe.date(null);
                }
            }
        }
    }
    appendCalendarIcon() {
        const groupAddon = document.createElement('span');
        const calendarIcon = document.createElement('span');
        groupAddon.setAttribute('class', 'input-group-addon calendar-addon');
        calendarIcon.setAttribute('class', 'glyphicon glyphicon-calendar');
        groupAddon.appendChild(calendarIcon);
        if (this.hasParent) {
            this.dpElement.append(groupAddon);
            this.dpElement.addClass('datepicker');
        }
        else {
            this.dpElement.parent().addClass('datepicker');
            this.dpElement.after(groupAddon);
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], NgTsDatepickerDirective.prototype, "date", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], NgTsDatepickerDirective.prototype, "options", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], NgTsDatepickerDirective.prototype, "dateChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], NgTsDatepickerDirective.prototype, "click", void 0);
NgTsDatepickerDirective = __decorate([
    Directive({
        // tslint:disable-next-line:directive-selector
        selector: '[ngTsDatepicker]'
    }),
    __metadata("design:paramtypes", [ElementRef])
], NgTsDatepickerDirective);

let NgTsDatepickerModule = class NgTsDatepickerModule {
};
NgTsDatepickerModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        exports: [
            NgTsDatepickerDirective
        ],
        declarations: [
            NgTsDatepickerDirective
        ]
    })
], NgTsDatepickerModule);

export { DATETIME_FORMAT, DATE_FORMAT, NgTsDatepickerDirective, NgTsDatepickerModule, TIME_FORMAT };
//# sourceMappingURL=ng-ts-datepicker.js.map
