import { __decorate, __metadata } from 'tslib';
import { Input, Output, EventEmitter, Directive, ElementRef, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as jqueryImport from 'jquery';
import 'eonasdan-bootstrap-datetimepicker';

var DATETIME_FORMAT = 'DD/MM/YYYY HH:mm:ss';
var DATE_FORMAT = 'DD/MM/YYYY';
var TIME_FORMAT = 'DD/MM/YYYY';

var jquery = jqueryImport;
var NgTsDatepickerDirective = /** @class */ (function () {
    function NgTsDatepickerDirective(el) {
        this.el = el;
        /**
         * Emits date selected from datepicker
         */
        this.dateChange = new EventEmitter();
        /**
         * Emits empty value once datepicker is clicked
         */
        this.click = new EventEmitter();
        this.defaultOptions = {
            allowInputToggle: true,
            format: DATETIME_FORMAT,
            preventInputKeys: true
        };
        this.hasParent = false;
        this.internalOptions = {};
    }
    NgTsDatepickerDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.internalOptions = Object.assign(this.internalOptions, this.defaultOptions, this.options);
        var $parent = jquery(this.el.nativeElement.parentNode);
        this.dpElement = $parent.hasClass('input-group') ? $parent : jquery(this.el.nativeElement);
        if ($parent.hasClass('input-group')) {
            this.dpElement = $parent;
            this.hasParent = true;
        }
        else {
            this.dpElement = jquery(this.el.nativeElement);
        }
        this.appendCalendarIcon();
        var datepickerOptions = Object.assign({}, this.internalOptions);
        delete datepickerOptions.preventInputKeys;
        this.dpElement.datetimepicker(datepickerOptions);
        this.dpElement.data('DateTimePicker').date(this.date);
        this.dpElement.on('dp.change', function (e) {
            if (e.date !== _this.date) {
                _this.date = e.date;
                _this.dateChange.emit(e.date);
            }
        });
        if (this.internalOptions.preventInputKeys) {
            this.dpElement.on('keydown', function (e) {
                e.preventDefault();
            });
        }
        this.dpElement.on('click', function (e) {
            _this.click.emit();
        });
    };
    NgTsDatepickerDirective.prototype.ngOnChanges = function (changes) {
        if (this.dpElement) {
            var dpe_1 = this.dpElement.data('DateTimePicker');
            if (!!dpe_1) {
                if (changes.options) {
                    jquery.map(changes.options.currentValue, function (value, key) {
                        dpe_1[key](value);
                    });
                }
                if (changes.date && changes.date.currentValue !== undefined) {
                    dpe_1.date(changes.date.currentValue);
                }
                else {
                    dpe_1.date(null);
                }
            }
        }
    };
    NgTsDatepickerDirective.prototype.appendCalendarIcon = function () {
        var groupAddon = document.createElement('span');
        var calendarIcon = document.createElement('span');
        groupAddon.setAttribute('class', 'input-group-addon calendar-addon');
        calendarIcon.setAttribute('class', 'glyphicon glyphicon-calendar');
        groupAddon.appendChild(calendarIcon);
        if (this.hasParent) {
            this.dpElement.append(groupAddon);
            this.dpElement.addClass('datepicker');
        }
        else {
            this.dpElement.parent().addClass('datepicker');
            this.dpElement.after(groupAddon);
        }
    };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], NgTsDatepickerDirective.prototype, "date", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], NgTsDatepickerDirective.prototype, "options", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NgTsDatepickerDirective.prototype, "dateChange", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NgTsDatepickerDirective.prototype, "click", void 0);
    NgTsDatepickerDirective = __decorate([
        Directive({
            // tslint:disable-next-line:directive-selector
            selector: '[ngTsDatepicker]'
        }),
        __metadata("design:paramtypes", [ElementRef])
    ], NgTsDatepickerDirective);
    return NgTsDatepickerDirective;
}());

var NgTsDatepickerModule = /** @class */ (function () {
    function NgTsDatepickerModule() {
    }
    NgTsDatepickerModule = __decorate([
        NgModule({
            imports: [
                CommonModule
            ],
            exports: [
                NgTsDatepickerDirective
            ],
            declarations: [
                NgTsDatepickerDirective
            ]
        })
    ], NgTsDatepickerModule);
    return NgTsDatepickerModule;
}());

export { DATETIME_FORMAT, DATE_FORMAT, NgTsDatepickerDirective, NgTsDatepickerModule, TIME_FORMAT };
//# sourceMappingURL=ng-ts-datepicker.js.map
